@@ -4,15 +4,8 @@
 # Copyright (c) 2010 Benoît HERVIER
 # Licenced under GPLv3
 '''A simple Twitter client made with pyqt4'''
-import sip
-sip.setapi('QString', 2)
-sip.setapi('QVariant', 2)
-
-from PyQt4.QtGui import *
-from PyQt4.QtCore import *
 
 from utils import *
-from notifications import KhweeteurNotification
 
 KHWEETEUR_TWITTER_CONSUMER_KEY = 'uhgjkoA2lggG4Rh0ggUeQ'
 KHWEETEUR_TWITTER_CONSUMER_SECRET = 'lbKAvvBiyTlFsJfb755t3y1LVwB0RaoMoDwLD14VvU'
@@ -21,23 +14,13 @@ KHWEETEUR_IDENTICA_CONSUMER_SECRET = '236fa46bf3f65fabdb1fd34d63c26d28'
 KHWEETEUR_STATUSNET_CONSUMER_KEY = '84e768bba2b6625f459a9a19f5d57bd1'
 KHWEETEUR_STATUSNET_CONSUMER_SECRET = 'fbc51241e2ab12e526f89c26c6ca5837'
 
-try:
-    from PyQt4.QtMobility.QtLocation import *
-#    from PySide.QtMobility.QtLocation import *
-    noQtLocation = False
-except:
-    noQtLocation = True
-
-try:
-    from PyQt4.QtMaemo5 import *
-#    from PySide.QtMaemo5 import *
-    isMAEMO = True
-except:
-    isMAEMO = False
-
 import oauth2 as oauth
+from notifications import KhweeteurNotification
 
 class KhweeteurPref(QMainWindow):
+
+    save = pyqtSignal()
+    
     DEFAULTTHEME = 'Default'
     WHITETHEME = 'White'
     COOLWHITETHEME = 'CoolWhite'
@@ -45,6 +28,7 @@ class KhweeteurPref(QMainWindow):
     THEMES = [DEFAULTTHEME, WHITETHEME, COOLWHITETHEME, COOLGRAYTHEME]
 
     def __init__(self, parent=None):
+        ''' Init the GUI Win'''
         QMainWindow.__init__(self,parent)
         self.parent = parent
 
@@ -60,30 +44,31 @@ class KhweeteurPref(QMainWindow):
             self.setAttribute(Qt.WA_Maemo5StackedWindow, True)
         self.setWindowTitle("Khweeteur Prefs")
 
-        self.setupGUI()
+        self._setupGUI()
         self.loadPrefs()
 
     def loadPrefs(self):
+        ''' Load and init default prefs to GUI'''
         if self.settings.value("refreshInterval"):
             self.refresh_value.setValue(int(self.settings.value("refreshInterval")))
         else:
             self.refresh_value.setValue(10)
         if self.settings.value("displayUser"):
-            self.displayUser_value.setCheckState(int(self.settings.value("displayUser")))
+            self.displayUser_value.setCheckState(Qt.CheckState(int(self.settings.value("displayUser"))))
         else:
-            self.displayUser_value.setCheckState(2)
+            self.displayUser_value.setCheckState(Qt.CheckState.Checked)
         if self.settings.value("displayAvatar"):
-            self.displayAvatar_value.setCheckState(int(self.settings.value("displayAvatar")))
+            self.displayAvatar_value.setCheckState(Qt.CheckState(int(self.settings.value("displayAvatar"))))
         if self.settings.value("displayTimestamp"):
-            self.displayTimestamp_value.setCheckState(int(self.settings.value("displayTimestamp")))
+            self.displayTimestamp_value.setCheckState(Qt.CheckState(int(self.settings.value("displayTimestamp"))))
         if self.settings.value("displayReplyTo"):
-            self.displayReplyTo_value.setCheckState(int(self.settings.value("displayReplyTo")))
+            self.displayReplyTo_value.setCheckState(Qt.CheckState(int(self.settings.value("displayReplyTo"))))
         if self.settings.value("useNotification"):
-            self.useNotification_value.setCheckState(int(self.settings.value("useNotification")))
+            self.useNotification_value.setCheckState(Qt.CheckState(int(self.settings.value("useNotification"))))
         if self.settings.value("useSerialization"):
-            self.useSerialization_value.setCheckState(int(self.settings.value("useSerialization")))
+            self.useSerialization_value.setCheckState(Qt.CheckState(int(self.settings.value("useSerialization"))))
         if self.settings.value("useBitly"):
-            self.useBitly_value.setCheckState(int(self.settings.value("useBitly")))
+            self.useBitly_value.setCheckState(Qt.CheckState(int(self.settings.value("useBitly"))))
         if not self.settings.value("theme"):
             self.settings.setValue("theme",KhweeteurPref.DEFAULTTHEME)
         if not self.settings.value("theme") in self.THEMES:
@@ -92,15 +77,16 @@ class KhweeteurPref(QMainWindow):
             self.settings.setValue("useAutoRotation",True)
         self.theme_value.setCurrentIndex(self.THEMES.index(self.settings.value("theme")))
         if self.settings.value("useAutoRotation"):
-            self.useAutoRotation_value.setCheckState(int(self.settings.value("useAutoRotation")))
+            self.useAutoRotation_value.setCheckState(Qt.CheckState(int(self.settings.value("useAutoRotation"))))
         if self.settings.value("useGPS"):
-            self.useGPS_value.setCheckState(int(self.settings.value("useGPS")))
+            self.useGPS_value.setCheckState(Qt.CheckState(int(self.settings.value("useGPS"))))
         if self.settings.value("tweetHistory"):
             self.history_value.setValue(int(self.settings.value("tweetHistory")))
         else:
             self.history_value.setValue(30)
 
     def savePrefs(self):
+        ''' Save the prefs from the GUI to QSettings''' 
         self.settings.setValue('refreshInterval', self.refresh_value.value())
         self.settings.setValue('displayUser', self.displayUser_value.checkState())
         self.settings.setValue('useNotification', self.useNotification_value.checkState())
@@ -113,12 +99,14 @@ class KhweeteurPref(QMainWindow):
         self.settings.setValue('useAutoRotation', self.useAutoRotation_value.checkState())
         self.settings.setValue('useGPS', self.useGPS_value.checkState())
         self.settings.setValue('tweetHistory', self.history_value.value())
-        self.emit(SIGNAL("save()"))
+        self.save.emit()
 
     def closeEvent(self,widget,*args):
+        ''' close event called when closing window'''
         self.savePrefs()
 
     def request_twitter_access_or_clear(self):
+        ''' Request or clear twitter auth token'''
         if self.settings.value('twitter_access_token'):
             self.settings.setValue('twitter_access_token_key','')
             self.settings.setValue('twitter_access_token_secret','')
@@ -143,12 +131,18 @@ class KhweeteurPref(QMainWindow):
                 ACCESS_TOKEN_URL  = 'https://api.twitter.com/oauth/access_token'
                 AUTHORIZATION_URL = 'https://api.twitter.com/oauth/authorize'
 
+                if isMAEMO:
+                    self.setAttribute(Qt.WA_Maemo5ShowProgressIndicator,True)
+
                 signature_method_hmac_sha1 = oauth.SignatureMethod_HMAC_SHA1()
                 oauth_consumer             = oauth.Consumer(key=KHWEETEUR_TWITTER_CONSUMER_KEY, secret=KHWEETEUR_TWITTER_CONSUMER_SECRET)
                 oauth_client               = oauth.Client(oauth_consumer)
 
                 resp, content = oauth_client.request(REQUEST_TOKEN_URL, 'GET')
 
+                if isMAEMO:
+                    self.setAttribute(Qt.WA_Maemo5ShowProgressIndicator,False)
+
                 if resp['status'] != '200':
                     KhweeteurNotification().warn(self.tr('Invalid respond from Twitter requesting temp token: %s') % resp['status'])
                 else:
@@ -185,6 +179,7 @@ class KhweeteurPref(QMainWindow):
                             self.setAttribute(Qt.WA_Maemo5ShowProgressIndicator,False)
 
     def request_identica_access_or_clear(self):
+        ''' Request or clear identi.ca auth token'''
         import urllib
         if self.settings.value('identica_access_token'):
             self.settings.setValue('identica_access_token_key','')
@@ -209,14 +204,20 @@ class KhweeteurPref(QMainWindow):
                 ACCESS_TOKEN_URL  = 'http://identi.ca/api/oauth/access_token'
                 AUTHORIZATION_URL = 'http://identi.ca/api/oauth/authorize'
 
+                if isMAEMO:
+                    self.setAttribute(Qt.WA_Maemo5ShowProgressIndicator,True)
+
                 signature_method_hmac_sha1 = oauth.SignatureMethod_HMAC_SHA1()
                 oauth_consumer             = oauth.Consumer(key=KHWEETEUR_IDENTICA_CONSUMER_KEY, secret=KHWEETEUR_IDENTICA_CONSUMER_SECRET)
                 oauth_client               = oauth.Client(oauth_consumer)
                 oauth_callback_uri = 'oob'
                 #Crappy hack for fixing oauth_callback not yet supported by the oauth2 lib but requested by identi.ca
                 resp, content = oauth_client.request(REQUEST_TOKEN_URL, 'POST', body=urllib.urlencode(dict(oauth_callback=oauth_callback_uri)))
-                write_log(resp)
-                write_log(content)
+#                write_log(resp)
+#                write_log(content)
+                if isMAEMO:
+                    self.setAttribute(Qt.WA_Maemo5ShowProgressIndicator,False)
+
                 if resp['status'] != '200':
                     KhweeteurNotification().warn(self.tr('Invalid respond from Identi.ca requesting temp token: %s') % resp['status'])
                 else:
@@ -234,8 +235,8 @@ class KhweeteurPref(QMainWindow):
 
                         oauth_client  = oauth.Client(oauth_consumer, token)
                         resp, content = oauth_client.request(ACCESS_TOKEN_URL, method='POST', body='oauth_verifier=%s' % str(pincode.strip()))
-                        write_log(resp)
-                        write_log(content)
+#                        write_log(resp)
+#                        write_log(content)
                         access_token  = dict(parse_qsl(content))
 
                         if resp['status'] != '200':
@@ -255,6 +256,7 @@ class KhweeteurPref(QMainWindow):
                             self.setAttribute(Qt.WA_Maemo5ShowProgressIndicator,False)
 
     def request_statusnet_access_or_clear(self):
+        ''' Request or clear status.net auth token'''
         QMessageBox.question(self,
            "Khweeteur",
            "Status.net isn't yet fully implemented",
@@ -325,8 +327,8 @@ class KhweeteurPref(QMainWindow):
                         if isMAEMO:
                             self.setAttribute(Qt.WA_Maemo5ShowProgressIndicator,False)
 
-    def setupGUI(self):
-#        self.aWidget = QWidget()
+    def _setupGUI(self):
+        ''' Create the gui content of the window'''
         self.scrollArea = QScrollArea(self)
         self.scrollArea.setWidgetResizable(True)
         self.aWidget = QWidget(self.scrollArea)
